/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import java.io.FileInputStream;
import java.io.IOException;

import dk.vajhoej.record.LengthProvider2;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.StructReaderStream;

/**
 * Class AcctFile represents a readable accounting data file.
 */
public class AcctFile {
	private LengthProvider2 lenpvd;
	private StructReaderStream srs;
	/**
	 * Construct instance.
	 * @param fnm accounting data file
	 * @throws IOException if error opening file
	 */
	public AcctFile(String fnm) throws IOException {
		lenpvd = new AcctRecProvider();
		srs = new StructReaderStream(new FileInputStream(fnm), lenpvd.getMaxLength(), 1000);
	}
	/**
	 * Read accounting record sequentially.
	 * @return accounting record read
	 * @throws RecordException if error parsing accounting record
	 * @throws IOException if error reading accounting record from accounting file
	 */
	public AcctRec read() throws RecordException, IOException {
		return srs.read(AcctRec.class, lenpvd);
	}
	/**
	 * More records.
	 * @return true if more records, false if no more records
	 * @throws IOException if error accessing accounting file
	 */
	public boolean more() throws IOException {
		return srs.more();
	}
	/**
	 * Close accounting file.
	 * @throws IOException if error closing accounting file
	 */
	public void close() throws IOException {
		srs.close();
	}
}
