/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Selector;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;
import dk.vajhoej.record.SubType;

/**
 * Class AcctPack represents an accounting packet.
 */
@Struct
public class AcctPack {
	@Selector(subtypes={@SubType(value=AcctPackType.ACR$K_ID,type=AcctPackID.class),
						@SubType(value=AcctPackType.ACR$K_RESOURCE,type=AcctPackResource.class),
						@SubType(value=AcctPackType.ACR$K_IMAGENAME,type=AcctPackImagename.class),
						@SubType(value=AcctPackType.ACR$K_FILENAME,type=AcctPackFilename.class),
						@SubType(value=AcctPackType.ACR$K_USER_DATA,type=AcctPackUserData.class),
						@SubType(value=AcctPackType.ACR$K_PRINT,type=AcctPackPrint.class)})
	@StructField(n=0,type=FieldType.STRUCT)
	private AcctPackType type;
	@StructField(n=1,type=FieldType.INT2)
	private short length;
	/**
	 * Get accounting packet type.
	 * @return accounting packet type
	 */
	public AcctPackType getType() {
		return type;
	}
	/**
	 * Get accounting packet length.
	 * @return accounting packet length
	 */
	public short getLength() {
		return length;
	}
	protected String subToString() {
		return "*"; // should be overriden
	}
	@Override
	public String toString() {
		return "(type=" + type + ",length=" + length + "," + subToString() + ")";
	}
}

