/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import java.io.UnsupportedEncodingException;

import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class AcctPackID represents an accounting packet with various ID's.
 */
@Struct
public class AcctPackID extends AcctPack {
	@StructField(n=2,type=FieldType.INT4)
	private int pid;
	@StructField(n=3,type=FieldType.INT4)
	private int owner;
	@StructField(n=4,type=FieldType.INT4)
	private int uic;
	@StructField(n=5,type=FieldType.INT8)
	private long priv;
	@StructField(n=6,type=FieldType.INT1)
	private int pri;
	@StructField(n=7,type=FieldType.INT1)
	private int idflgs;
	@StructField(n=8,type=FieldType.INT2)
	private short offset_username;
	@StructField(n=9,type=FieldType.INT2)
	private short offset_account;
	@StructField(n=10,type=FieldType.INT2)
	private short offset_nodename;
	@StructField(n=11,type=FieldType.INT2)
	private short offset_terminal;
	@StructField(n=12,type=FieldType.INT2)
	private short offset_jobname;
	@StructField(n=13,type=FieldType.INT4)
	private int jobid;
	@StructField(n=14,type=FieldType.INT2)
	private short offset_queue;
	@StructField(n=15,type=FieldType.INT2)
	private short offset_nodeaddr;
	@StructField(n=16,type=FieldType.INT2)
	private short offset_remoteid;
	@StructField(n=17,type=FieldType.INT2)
	private short offset_fulladdr;
	@StructField(n=18,type=FieldType.INT2)
	private short offset_fullname;
	@ArrayField(elements=0)
	@StructField(n=19,type=FieldType.INT1)
	private byte[] buf = new byte[0];
	/*
	@StructField(n=19,type=FieldType.VARSTR,prefixlength=1)
	public String username;
	@StructField(n=20,type=FieldType.VARSTR,prefixlength=1)
	public String account;
	@StructField(n=21,type=FieldType.VARSTR,prefixlength=1)
	public String nodename;
	@StructField(n=22,type=FieldType.VARSTR,prefixlength=1)
	public String terminal;
	@StructField(n=23,type=FieldType.VARSTR,prefixlength=1)
	public String jobname;
	@StructField(n=24,type=FieldType.VARSTR,prefixlength=1)
	public String queue;
	@StructField(n=25,type=FieldType.VARSTR,prefixlength=1)
	public String nodeaddr;
	@StructField(n=26,type=FieldType.VARSTR,prefixlength=1)
	public String remoteid;
	@StructField(n=27,type=FieldType.VARSTR,prefixlength=1)
	public String fulladdr;
	@StructField(n=28,type=FieldType.VARSTR,prefixlength=1)
	public String fullname;
	*/
	/**
	 * Get PID.
	 * @return PID
	 */
	public int getPid() {
		return pid;
	}
	/**
	 * Get parent process PID.
	 * @return parent process PID
	 */
	public int getOwner() {
		return owner;
	}
	/**
	 * Get UIC.
	 * @return UIC
	 */
	public int getUic() {
		return uic;
	}
	/**
	 * Get priv mask.
	 * @return priv mask
	 */
	public long getPriv() {
		return priv;
	}
	/** Get priority.
	 * @return priority
	 */
	public int getPri() {
		return pri;
	}
	/**
	 * Get flags.
	 * @return flags
	 */
	public int getIdflgs() {
		return idflgs;
	}
	/**
	 * Get job ID.
	 * @return jobID
	 */
	public int getJobid() {
		return jobid;
	}
	private String getXxxx(int offset) {
		if(offset <= 50) return "";
		try {
			return new String(buf, offset+1-50, buf[offset-50] & 0xFF, "ISO-8859-1");
		} catch (UnsupportedEncodingException e) {
			throw new RuntimeException("No ISO-8859-1 support");
		}
	}
	/**
	 * Get username.
	 * @return username
	 */
	public String getUsername() {
		return getXxxx(offset_username);
	}
	/**
	 * Get account name.
	 * @return account name
	 */
	public String getAccount() {
		return getXxxx(offset_account);
	}
	/**
	 * Get node name.
	 * @return node name
	 */
	public String getNodename() {
		return getXxxx(offset_nodename);
	}
	/**
	 * Get terminal.
	 * @return terminal
	 */
	public String getTerminal() {
		return getXxxx(offset_terminal);
	}
	/**
	 * Get job name.
	 * @return job name
	 */
	public String getJobname() {
		return getXxxx(offset_jobname);
	}
	/**
	 * Get queue name.
	 * @return queue name
	 */
	public String getQueue() {
		return getXxxx(offset_queue);
	}
	/**
	 * Get node address.
	 * @return node address
	 */
	public String getNodeaddr() {
		return getXxxx(offset_nodeaddr);
	}
	/**
	 * Get remote ID.
	 * @return remote ID
	 */
	public String getRemoteid() {
		return getXxxx(offset_remoteid);
	}
	/**
	 * Get remote node address.
	 * @return remote node address
	 */
	public String getFulladdr() {
		return getXxxx(offset_fulladdr);
	}
	/**
	 * Get remote node name.
	 * @return remote node name
	 */
	public String getFullname() {
		return getXxxx(offset_fullname);
	}
	protected String subToString() {
		return "pid=" + pid + ",username=" + getUsername();
	}
}
